import type { Actions, PageServerLoad } from "./$types";

import { API_URL } from "$env/static/private";
import type { Chapter, Group } from "$lib/types";
import { error, fail, redirect } from "@sveltejs/kit";

export const load: PageServerLoad = async ({ locals, fetch }) => {
  if (!locals.user || !locals.user.email.endsWith('@peerat.dev')) {
    redirect(302, '/');
  }

  let chapters: Chapter[] = [];

  let res = await fetch(API_URL + "/chapters");

  if (res.ok) {
    chapters = await res.json();
  } else {
    console.error("Error fetching chapters");
  }

  const event = chapters?.filter((chapter) => chapter.start && chapter.end).pop();

  if (!event) {
    error(404);
  }

  res = await fetch(`${API_URL}/groups/${event.id}`);

  if (!res.ok) redirect(302, "/chapters/" + event.id);

  const groups: Group[] = await res.json();

  return {
    title: "Broadcast" + " - " + event.name,

    event,
    groups,
  };
};

export const actions: Actions = {
  default: async ({ request, locals, fetch }) => {
    if (!locals.user || !locals.user.email.endsWith('@peerat.dev')) {
      return fail(401);
    }

    const data = await request.formData();

    const message = data.get('message') as string;
    const group = data.get('group') as string;

    const body = group.length ? { group, message } : { message };

    const res = await fetch(API_URL + "/admin/event/", {
      method: "POST",
      body: JSON.stringify(body),
    });

    console.log(res);
  },
};
